// import {
//   csv,
//   format,
//   select
// } from 'd3';
import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  schemeCategory10,
  scaleOrdinal,
  axisBottom
} from 'd3';

import { dropdownMenu } from './dropdownMenu';
import { scatterPlot } from './scatterPlot';
import { colorLegend } from './colorLegend';

const svg = select('svg');

const width = +svg.attr('width') ,
      height = +svg.attr('height');

let data,
    xColumn,
    yColumn;
let colorColumn;

// const render = () => {

//   const onXColumnClicked = column => {
//     xColumn = column;
//     render();
//   }  
//   const onYColumnClicked = column => {
//     yColumn = column;
//     render();
//   }

//   select('.x-menu')
//     .call(dropdownMenu, {
//       options: data.columns.sort(),
//     	onOptionClick: onXColumnClicked,
//     	initialValue: xColumn
//     });
  
//   select('.y-menu')
//     .call(dropdownMenu, {
//       options: data.columns.sort(),
//     	onOptionClick: onYColumnClicked,
//     	initialValue: yColumn
//     });

  
//   svg.call(scatterPlot, {
//     data,
//     xValue: d => d[xColumn],
//     xAxisLabel: xColumn,
//     yValue: d => d[yColumn],
//     yAxisLabel: yColumn,
//     circleRadius: 10,
//     margin: {top: 60, right: 40, bottom: 60, left: 120},
//     width,
//     height
//   });
  
// };

  
  
const onXColumnClicked = column => {
  xColumn = column;
  render();
};

const onYColumnClicked = column => {
  yColumn = column;
  render();
};

const onColorColumnClicked = column => {
  colorColumn = column;
  render();
};

const render = () => {
  
  const colorValue = d => d[colorColumn];
  
  const colorScale = scaleOrdinal()
    .domain(data.map(colorValue))
    .range(schemeCategory10);

    select('.x-menu')
    .call(dropdownMenu, {
      options: data.columns.sort(),
    	onOptionClick: onXColumnClicked,
    	initialValue: xColumn
    });
  
  select('.y-menu')
    .call(dropdownMenu, {
      options: data.columns.sort(),
    	onOptionClick: onYColumnClicked,
    	initialValue: yColumn
    });
  
  select('.color-menu')
    .call(dropdownMenu, {
      options: data.columns,
      onOptionClick: onColorColumnClicked,
      selectedOption: colorColumn
    });
  
 const circleRadius = 10;
  svg.call(scatterPlot, {
    xValue: d => d[xColumn],
    xAxisLabel: xColumn,
    yValue: d => d[yColumn],
    colorScale,
    colorValue,
    circleRadius,
    yAxisLabel: yColumn,
    margin: { top: 10, right: 180, bottom: 108, left: 150 },
    width,
    height,
    data
  });
  
  svg.append('g')
    .attr('transform', `translate(800,50)`)
    .call(colorLegend, {
      colorScale,
      circleRadius,
      spacing: 40,
      textOffset: 20
    });
};

csv('https://gist.githubusercontent.com/ReinaFeng/3af261c92405fe41071f982a8a399ae0/raw/579e75d6ab3f3f8ee9532861c6d78d0d2ae36068/who-aap-database-may2016.csv')
  .then(loadedData => {
    data = loadedData;
  console.log(loadedData)
    data.forEach(d => {
      d.X = +d.X;
      d.Y = +d.Y;
      d.DMC = +d.DMC;
      d.DC = +d.DC;
      d.ISI = +d.ISI;
      d.FFMC = +d.FFMC;
      d.rain = +d.rain;
      d.temp = +d.temp;
      d.wind = +d.wind;
      d.area = +d.area
      d.RH = +d.RH; 
    });
    xColumn = data.columns[5];
    yColumn = data.columns[9];
    colorColumn = data.columns[1];
  
    render();
  });

