import {
  axisBottom,
  axisLeft,
  extent,
  scaleLinear,
  select,
  csv,
  format
} from 'd3';

export const scatterPlot = (selection, props) => {
  const {
    data,
    xValue,
    xAxisLabel,
    yValue,
    colorValue,
    colorScale,
    yAxisLabel,
    circleRadius,
    margin,
    width,
    height
  } = props;
  
  const innerWidth = width - margin.left - margin.right,
        innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	.domain(extent(data, xValue))
  	.range([0, 180])
  	.nice();
  
  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([0, 280])
  	.nice();
  
  const g = selection.selectAll('.container').data([null]);
  const gEnter = g.enter().append('g')
  	.attr('class', 'container');
  
  gEnter.merge(g)
  		.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(10);
  
  const yAxisG = g.select('.y-axis');
  const yAxisGEnter = gEnter
    .append('g')
  		.attr('class', 'y-axis');
  yAxisG
  	.merge(yAxisGEnter)
  		.call(yAxis)
  		.selectAll('.domain').remove();
  
  const yAxisLabelText = yAxisGEnter
  	.append('text')
  		.attr('class', 'axis-label')
      .attr('fill', '#999')
      .attr('y', -60)
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
  	.merge(yAxisG.select('.axis-label'))
      .attr('x', -innerHeight/2)
      .text(yAxisLabel)
  
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(10);
  
  const xAxisG = g.select('.x-axis');
  const xAxisGEnter = gEnter
    .append('g')
  		.attr('class', 'x-axis');
  xAxisG
  	.merge(xAxisGEnter)
  		.attr('transform', `translate(0, ${innerHeight})`)
  		.call(xAxis)
  		.selectAll('.domain').remove();
   
    const xAxisLabelText = xAxisGEnter
  	.append('text')
  		.attr('class', 'axis-label')
      .attr('fill', '#999')
      .attr('y', 40)
  	.merge(xAxisG.select('.axis-label'))
      .attr('x', innerWidth/2)
      .text(xAxisLabel)
  
  
  const circle = g.merge(gEnter)
  	.selectAll('circle').data(data);
  
  circle.enter().append('circle')
  		.attr('cy', d => innerHeight/2)
  		.attr('cx', d => innerWidth/2)
  		.attr('r', 0)
  	.merge(circle)
  			.attr('fill', d => colorScale(colorValue(d)))
  		.transition().duration(1000)
  		.delay((d, i) => i * 5)
        .attr('cy', d => yScale(yValue(d)))
        .attr('cx', d => xScale(xValue(d)))
        .attr('r', circleRadius);
  
  circle.exit().remove();
  
}